@@ -875,9 +875,10 @@ class Server(object):
 
         for vlist in value_lists:
             if vlist['name'] == name:
-                values += [(v['value'], v['displayValue']) for v in vlist['values']]
+                values += [(v['value'], v.get('displayValue', '')) for v in vlist['values']]
                 break
 
+
         return values
 
     def _call_filemaker(self, method: str, path: str,
